# OCI Analytics MCP Server

## Overview
This server provides tools to interact with the OCI Analytics service.

## Warning

This is a placeholder package and should not be used.

## License

Copyright (c) 2025 Oracle and/or its affiliates.
 
Released under the Universal Permissive License v1.0 as shown at  
<https://oss.oracle.com/licenses/upl/>.
